package util

import (
	"os"
	"path/filepath"
	"sort"
	"strings"
)

func ListAbsolutePathWithSuffixAndSort(dir string, suffix string) ([]string, error) {
	var result []string
	if !strings.HasSuffix(dir, "/") {
		dir = dir + "/"
	}
	files, err := os.ReadDir(dir)
	if err != nil {
		return nil, err
	}
	for _, file := range files {
		if strings.HasSuffix(file.Name(), suffix) {
			result = append(result, dir+file.Name())
		}
	}
	// 根据文件名进行升序排序
	sort.Slice(result, func(i, j int) bool {
		return filepath.Base(result[i]) < filepath.Base(result[j])
	})
	return result, nil
}

// RemoveDir 递归删除目录及其下的所有文件和子目录
func RemoveDir(dirPath string) error {
	// 打开目录
	dir, err := os.Open(dirPath)
	if err != nil {
		return err
	}
	defer dir.Close()
	// 读取目录下的文件和子目录
	fileInfos, err := dir.Readdir(-1)
	if err != nil {
		return err
	}
	// 遍历文件和子目录
	for _, fileInfo := range fileInfos {
		path := filepath.Join(dirPath, fileInfo.Name())

		if fileInfo.IsDir() {
			// 如果是子目录，递归调用removeDir删除子目录及其下的文件和子目录
			RemoveDir(path)

		} else {
			// 如果是文件，直接删除文件
			err = os.Remove(path)
			if err != nil {
				return err
			}
		}
	}
	// 删除目录本身
	err = os.Remove(dirPath)
	if err != nil {
		return err
	}
	return nil
}
